certi-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[certi-cvs] certi libCERTI/NM_Classes.hh libCERTI/NetworkMe...


From: certi-cvs
Subject: [certi-cvs] certi libCERTI/NM_Classes.hh libCERTI/NetworkMe...
Date: Mon, 23 Jun 2008 13:25:07 +0000

CVSROOT:        /sources/certi
Module name:    certi
Changes by:     Eric NOULARD <erk>      08/06/23 13:25:06

Modified files:
        libCERTI       : NM_Classes.hh NetworkMessage.hh 
                         ObjectClassSet.hh PosixClock.hh Subscribable.cc 
                         Clock.hh PosixClock.cc LBTS.cc MessageBuffer.cc 
                         Named.cc FedRegion.hh Named.hh Clock.cc 
                         ObjectClassSet.cc 
        test/Billard   : Billard.cc 
        RTIA           : FederationManagement.cc 
        RTIG           : Federation.cc 

Log message:
        Merge in Petr patch for
        bug #23666 : Compilation errors with Sun Studio 12

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/NM_Classes.hh?cvsroot=certi&r1=3.6&r2=3.7
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/NetworkMessage.hh?cvsroot=certi&r1=3.38&r2=3.39
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/ObjectClassSet.hh?cvsroot=certi&r1=3.29&r2=3.30
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/PosixClock.hh?cvsroot=certi&r1=4.2&r2=4.3
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/Subscribable.cc?cvsroot=certi&r1=3.7&r2=3.8
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/Clock.hh?cvsroot=certi&r1=4.4&r2=4.5
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/PosixClock.cc?cvsroot=certi&r1=4.3&r2=4.4
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/LBTS.cc?cvsroot=certi&r1=3.10&r2=3.11
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/MessageBuffer.cc?cvsroot=certi&r1=3.10&r2=3.11
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/Named.cc?cvsroot=certi&r1=3.5&r2=3.6
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/FedRegion.hh?cvsroot=certi&r1=3.2&r2=3.3
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/Named.hh?cvsroot=certi&r1=3.4&r2=3.5
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/Clock.cc?cvsroot=certi&r1=4.3&r2=4.4
http://cvs.savannah.gnu.org/viewcvs/certi/libCERTI/ObjectClassSet.cc?cvsroot=certi&r1=3.37&r2=3.38
http://cvs.savannah.gnu.org/viewcvs/certi/test/Billard/Billard.cc?cvsroot=certi&r1=3.37&r2=3.38
http://cvs.savannah.gnu.org/viewcvs/certi/RTIA/FederationManagement.cc?cvsroot=certi&r1=3.67&r2=3.68
http://cvs.savannah.gnu.org/viewcvs/certi/RTIG/Federation.cc?cvsroot=certi&r1=3.92&r2=3.93

Patches:
Index: libCERTI/NM_Classes.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/NM_Classes.hh,v
retrieving revision 3.6
retrieving revision 3.7
diff -u -b -r3.6 -r3.7
--- libCERTI/NM_Classes.hh      11 Jun 2008 15:19:21 -0000      3.6
+++ libCERTI/NM_Classes.hh      23 Jun 2008 13:25:02 -0000      3.7
@@ -43,7 +43,7 @@
        virtual void serialize(MessageBuffer& msgBuffer);
        virtual void deserialize(MessageBuffer& msgBuffer);     
        /* specific Getter/Setter */    
-       AttributeHandle getHandle(int i) {return handleArray[i];};
+       AttributeHandle getHandle(int i) const {return handleArray[i];};
        void setHandle(AttributeHandle h, int i) {handleArray[i]=h;};
 protected:
        /* specific field */
@@ -59,22 +59,22 @@
        virtual void deserialize(MessageBuffer& msgBuffer) = 0; 
        /* specific Getter/Setter */    
        const SpaceHandle getSpace() const {return space;};
-       void setSpace(SpaceHandle space) {this->space=space;};
+       void setSpace(SpaceHandle newSpace) {space=newSpace;};
 
        const int32_t geNbExtents() const {return nbExtents;};
-       void setNbExtents(int32_t nbExtents) {this->nbExtents=nbExtents;};
+       void setNbExtents(int32_t newNbExtents) {nbExtents=newNbExtents;};
 
        const int32_t getRegion() const {return region;};
-       void setRegion(int32_t region) {this->region=region;};  
+       void setRegion(int32_t newRegion) {region=newRegion;};  
 
        const ObjectHandle getObject() const {return object;};
-       void setObject(ObjectHandle object) {this->object=object;};
+       void setObject(ObjectHandle newObject) {object=newObject;};
 
        const ObjectClassHandle getObjectClass() const {return objectClass;};
-       void setObjectClass(ObjectClassHandle objectClass) 
{this->objectClass=objectClass;};
+       void setObjectClass(ObjectClassHandle newObjectClass) 
{objectClass=newObjectClass;};
 
        const InteractionClassHandle getInteractionClass() const {return 
interactionClass;};
-       void setInteractionClass(InteractionClassHandle interactionClass) 
{this->interactionClass=interactionClass;};
+       void setInteractionClass(InteractionClassHandle newInteractionClass) 
{interactionClass=newInteractionClass;};
 protected:
        /* specific field */
        bool DDM_bool;
@@ -624,7 +624,7 @@
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
        const InteractionClassHandle getInteractionClassHandle() const {return 
interactionClass;};
-       void setInteractionClassHandle(InteractionClassHandle interactionClass) 
{this->interactionClass=interactionClass;};
+       void setInteractionClassHandle(InteractionClassHandle 
newInteractionClass) {interactionClass=newInteractionClass;};
 protected:
        /* specific field */
        //      InteractionClassHandle interactionClass;
@@ -946,7 +946,7 @@
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
        const ObjectHandle getObject() const {return object;};
-       void setObject(ObjectHandle object) {this->object=object;};
+       void setObject(ObjectHandle newObject) {object=newObject;};
 protected:
        /* specific field */
 private:
@@ -1206,9 +1206,9 @@
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
        const SpaceHandle getSpace() const {return space;};
-       void setSpace(SpaceHandle space) {this->space=space;};  
+       void setSpace(SpaceHandle newSpace) {space=newSpace;};  
        const int32_t getRegion() const {return region;};
-       void setRegion(SpaceHandle region) {this->region=region;};
+       void setRegion(SpaceHandle newRegion) {region=newRegion;};
 protected:
        /* specific field */
        //      SpaceHandle space;
@@ -1229,7 +1229,7 @@
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
        const int32_t getRegion() const {return region;};
-       void setRegion(SpaceHandle region) {this->region=region;};
+       void setRegion(SpaceHandle newRegion) {region=newRegion;};
 protected:
        /* specific field */
        //      int32_t region;
@@ -1248,7 +1248,7 @@
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
        const int32_t getRegion() const {return region;};
-       void setRegion(SpaceHandle region) {this->region=region;};
+       void setRegion(SpaceHandle newRegion) {region=newRegion;};
 protected:
        /* specific field */
        //      int32_t region; 
@@ -1267,9 +1267,9 @@
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
        const int32_t getRegion() const {return region;};
-       void setRegion(SpaceHandle region) {this->region=region;};
+       void setRegion(SpaceHandle newRegion) {region=newRegion;};
        const ObjectHandle getObject() const {return object;};
-       void setObject(ObjectHandle object) {this->object=object;};             
+       void setObject(ObjectHandle newObject) {object=newObject;};
 protected:
        /* specific field */
        //      int32_t      region;
@@ -1396,12 +1396,12 @@
        virtual void serialize(MessageBuffer& msgBuffer);
        virtual void deserialize(MessageBuffer& msgBuffer);
        /* specific Getter/Setter */
-       void setFEDid(std::string FEDid) {this->FEDid=FEDid;};
+       void setFEDid(std::string newFEDid) {FEDid=newFEDid;};
        const std::string getFEDid() const {return FEDid;};
        //      void setLineFollows() {lineFollows=true;};
        //      void unsetLineFollows() {lineFollows=true;};
        //const bool getLineFollows() {return lineFollows;};
-       void setFEDLine(std::string line) {this->line=line;};
+       void setFEDLine(std::string newLine) {line=newLine;};
        std::string getFEDLine() {return line;};
 protected:
        /* specific field */

Index: libCERTI/NetworkMessage.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/NetworkMessage.hh,v
retrieving revision 3.38
retrieving revision 3.39
diff -u -b -r3.38 -r3.39
--- libCERTI/NetworkMessage.hh  11 Jun 2008 15:19:22 -0000      3.38
+++ libCERTI/NetworkMessage.hh  23 Jun 2008 13:25:04 -0000      3.39
@@ -17,7 +17,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: NetworkMessage.hh,v 3.38 2008/06/11 15:19:22 rousse Exp $
+// $Id: NetworkMessage.hh,v 3.39 2008/06/23 13:25:04 erk Exp $
 // ----------------------------------------------------------------------------
 
 #ifndef CERTI_NETWORK_MESSAGE_HH
@@ -223,7 +223,7 @@
         * If ones set Date then this is a Dated message
         * Message builder which setDate will generate a Dated message 
         */
-       void setDate(FederationTime date) {_isDated=true; this->date = date;};
+       void setDate(FederationTime new_date) {_isDated=true; date = new_date;};
        const FederationTime getDate() const {return this->date;};
 
        unsigned long multicastAddress ;
@@ -232,7 +232,7 @@
         * Indicate if the message is Labelled or not
         */
        bool isLabelled() {return _isLabelled;};        
-       void setLabel(const std::string label) {_isLabelled = true; this->label 
= label;};
+       void setLabel(const std::string new_label) {_isLabelled = true; label = 
new_label;};
        void setLabel(const char *new_label) {_isLabelled = true; label = 
std::string(new_label); }
        const std::string getLabel() const {return this->label;};
 
@@ -240,7 +240,7 @@
         * Indicate if the message is Tagged or not
         */
        bool isTagged() {return _isTagged;};
-       void setTag(const std::string tag) {_isTagged = true; this->tag = tag;};
+       void setTag(const std::string new_tag) {_isTagged = true; tag = 
new_tag;};
        void setTag(const char *new_tag) {_isTagged = true; tag = 
std::string(new_tag); }
        const std::string getTag() const {return this->tag;};
 
@@ -354,4 +354,4 @@
 
 #endif // CERTI_NETWORK_MESSAGE_HH
 
-// $Id: NetworkMessage.hh,v 3.38 2008/06/11 15:19:22 rousse Exp $
+// $Id: NetworkMessage.hh,v 3.39 2008/06/23 13:25:04 erk Exp $

Index: libCERTI/ObjectClassSet.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/ObjectClassSet.hh,v
retrieving revision 3.29
retrieving revision 3.30
diff -u -b -r3.29 -r3.30
--- libCERTI/ObjectClassSet.hh  11 Jun 2008 15:19:22 -0000      3.29
+++ libCERTI/ObjectClassSet.hh  23 Jun 2008 13:25:04 -0000      3.30
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: ObjectClassSet.hh,v 3.29 2008/06/11 15:19:22 rousse Exp $
+// $Id: ObjectClassSet.hh,v 3.30 2008/06/23 13:25:04 erk Exp $
 // ----------------------------------------------------------------------------
 
 #ifndef _CERTI_OBJECT_CLASS_SET_HH
@@ -47,7 +47,7 @@
 {
 
 public:
-    ObjectClassSet(SecurityServer *theSecurityServer, bool 
isRootClassSet=false);
+    ObjectClassSet(SecurityServer *theSecurityServer, bool 
newIsRootClassSet=false);
     ~ObjectClassSet();
 
     void addClass(ObjectClass *theClass) throw (RTIinternalError);
@@ -210,4 +210,4 @@
 
 #endif // _CERTI_OBJECT_CLASS_SET_HH
 
-// $Id: ObjectClassSet.hh,v 3.29 2008/06/11 15:19:22 rousse Exp $
+// $Id: ObjectClassSet.hh,v 3.30 2008/06/23 13:25:04 erk Exp $

Index: libCERTI/PosixClock.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/PosixClock.hh,v
retrieving revision 4.2
retrieving revision 4.3
diff -u -b -r4.2 -r4.3
--- libCERTI/PosixClock.hh      30 Jul 2007 07:30:21 -0000      4.2
+++ libCERTI/PosixClock.hh      23 Jun 2008 13:25:04 -0000      4.3
@@ -22,7 +22,7 @@
         *      - CLOCK_REALTIME_HR
         *      - CLOCK_MONOTONIC_HR
         */
-       PosixClock(clockid_t clockId=CLOCK_REALTIME);
+       PosixClock(clockid_t newClockId=CLOCK_REALTIME);
        /**
         * Get the clock resolution in nano-seconds.
         * @return the clock resolution in nano-seconds

Index: libCERTI/Subscribable.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/Subscribable.cc,v
retrieving revision 3.7
retrieving revision 3.8
diff -u -b -r3.7 -r3.8
--- libCERTI/Subscribable.cc    12 Jun 2008 07:39:48 -0000      3.7
+++ libCERTI/Subscribable.cc    23 Jun 2008 13:25:04 -0000      3.8
@@ -17,7 +17,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: Subscribable.cc,v 3.7 2008/06/12 07:39:48 erk Exp $
+// $Id: Subscribable.cc,v 3.8 2008/06/23 13:25:04 erk Exp $
 // ----------------------------------------------------------------------------
 
 
@@ -107,7 +107,9 @@
 void
 Subscribable::unsubscribe(FederateHandle fed)
 {
-    subscribers.remove_if(HandleComparator<Subscriber>(fed));
+    std::remove_if(subscribers.begin(),
+                   subscribers.end(),
+                   HandleComparator<Subscriber>(fed));
 }
 
 // ----------------------------------------------------------------------------
@@ -199,4 +201,4 @@
 
 } // namespace certi
 
-// $Id: Subscribable.cc,v 3.7 2008/06/12 07:39:48 erk Exp $
+// $Id: Subscribable.cc,v 3.8 2008/06/23 13:25:04 erk Exp $

Index: libCERTI/PosixClock.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/PosixClock.cc,v
retrieving revision 4.3
retrieving revision 4.4
diff -u -b -r4.3 -r4.4
--- libCERTI/PosixClock.cc      10 Aug 2007 11:32:16 -0000      4.3
+++ libCERTI/PosixClock.cc      23 Jun 2008 13:25:05 -0000      4.4
@@ -4,10 +4,10 @@
 
 namespace certi {
 
-PosixClock::PosixClock(clockid_t clockId) : Clock("PosixClock")
+PosixClock::PosixClock(clockid_t newClockId) : Clock("PosixClock")
 {
-               this->clockId = clockId;
-               clock_getres(clockId,&this->resolution);
+    clockId = newClockId;
+    clock_getres(newClockId, &resolution);
 }   
 
 double 

Index: libCERTI/LBTS.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/LBTS.cc,v
retrieving revision 3.10
retrieving revision 3.11
diff -u -b -r3.10 -r3.11
--- libCERTI/LBTS.cc    23 Apr 2008 13:03:28 -0000      3.10
+++ libCERTI/LBTS.cc    23 Jun 2008 13:25:05 -0000      3.11
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: LBTS.cc,v 3.10 2008/04/23 13:03:28 erk Exp $
+// $Id: LBTS.cc,v 3.11 2008/06/23 13:25:05 erk Exp $
 // ----------------------------------------------------------------------------
 
 
@@ -94,7 +94,11 @@
 LBTS::get(std::vector<FederateClock> &v) const
 {
     v.reserve(v.size() + clocks.size());
-    std::copy(clocks.begin(), clocks.end(), std::back_inserter(v));
+    // append clocks to v
+    // note, the ClockSet::value_type and FederateClock differ in const-ness
+    for(ClockSet::const_iterator pos = clocks.begin();
+        pos != clocks.end(); pos++)
+        v.push_back(FederateClock(pos->first, pos->second));
 }
 
 // ----------------------------------------------------------------------------
@@ -155,4 +159,4 @@
 
 } // namespace certi
 
-// $Id: LBTS.cc,v 3.10 2008/04/23 13:03:28 erk Exp $
+// $Id: LBTS.cc,v 3.11 2008/06/23 13:25:05 erk Exp $

Index: libCERTI/MessageBuffer.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/MessageBuffer.cc,v
retrieving revision 3.10
retrieving revision 3.11
diff -u -b -r3.10 -r3.11
--- libCERTI/MessageBuffer.cc   12 Jun 2008 07:39:49 -0000      3.10
+++ libCERTI/MessageBuffer.cc   23 Jun 2008 13:25:05 -0000      3.11
@@ -205,7 +205,7 @@
 int32_t MessageBuffer::read_uint8s(uint8_t* data, uint32_t n) {        
        if (n + readOffset > writeOffset) {
                std::stringstream smsg;
-               smsg << __func__ << "::invalid read of size <" << n
+               smsg << "read_uint8s::invalid read of size <" << n
                                << "> inside a buffer of readable size <"
                                << (int32_t)writeOffset-readOffset << "> 
(writeOffset="
                                <<writeOffset << ",readOffset="<<readOffset 
<<").";
@@ -249,7 +249,7 @@
        
        if (2*n + readOffset > writeOffset) {
                std::stringstream smsg;
-               smsg << __func__ << "::invalid read of size <" << 2*n
+               smsg << "read_uint16s::invalid read of size <" << 2*n
                                << "> inside a buffer of readable size <"
                                << (int32_t)writeOffset-readOffset << "> 
(writeOffset="
                                <<writeOffset << ",readOffset="<<readOffset 
<<").";
@@ -303,7 +303,7 @@
        
        if (4*n + readOffset > writeOffset) {
                std::stringstream smsg;
-               smsg << __func__ << "::invalid read of size <" << 4*n
+               smsg << "read_uint32s::invalid read of size <" << 4*n
                                << "> inside a buffer of readable size <"
                                << (int32_t)writeOffset-readOffset << "> 
(writeOffset="
                                <<writeOffset << ",readOffset="<<readOffset 
<<").";
@@ -370,7 +370,7 @@
        
        if (8*n + readOffset > writeOffset) {
                std::stringstream smsg;
-               smsg << __func__ << "::invalid read of size <" << 4*n
+               smsg << "read_uint64s::invalid read of size <" << 4*n
                                << "> inside a buffer of readable size <"
                                << (int32_t)writeOffset-readOffset << "> 
(writeOffset="
                                <<writeOffset << ",readOffset="<<readOffset 
<<").";

Index: libCERTI/Named.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/Named.cc,v
retrieving revision 3.5
retrieving revision 3.6
diff -u -b -r3.5 -r3.6
--- libCERTI/Named.cc   9 Dec 2007 16:26:49 -0000       3.5
+++ libCERTI/Named.cc   23 Jun 2008 13:25:05 -0000      3.6
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: Named.cc,v 3.5 2007/12/09 16:26:49 erk Exp $
+// $Id: Named.cc,v 3.6 2008/06/23 13:25:05 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include "Named.hh"
@@ -28,20 +28,20 @@
 
 Named::Named() { }
 
-Named::Named(std::string name)
-    : name(name) { }
+Named::Named(std::string newName)
+    : name(newName) { }
 
 Named::~Named() {}
 
 void
-Named::setName(std::string name)
+Named::setName(std::string newName)
 {
-    this->name = name ;
+    name = newName ;
 }
 
 void 
-Named::setName(const char* name) {
-    this->name = name;
+Named::setName(const char* newName) {
+    name = newName;
 }
 
 const std::string
@@ -58,9 +58,9 @@
 }
 
 bool
-Named::isNamed(const std::string &name) const
+Named::isNamed(const std::string &newName) const
 {
-    return (this->name == name) ;
+    return (name == newName);
 }
 
 bool
@@ -95,4 +95,4 @@
 
 } // certi
 
-// $Id: Named.cc,v 3.5 2007/12/09 16:26:49 erk Exp $
+// $Id: Named.cc,v 3.6 2008/06/23 13:25:05 erk Exp $

Index: libCERTI/FedRegion.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/FedRegion.hh,v
retrieving revision 3.2
retrieving revision 3.3
diff -u -b -r3.2 -r3.3
--- libCERTI/FedRegion.hh       22 Jun 2007 08:51:36 -0000      3.2
+++ libCERTI/FedRegion.hh       23 Jun 2008 13:25:05 -0000      3.3
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: FedRegion.hh,v 3.2 2007/06/22 08:51:36 erk Exp $
+// $Id: FedRegion.hh,v 3.3 2008/06/23 13:25:05 erk Exp $
 // ----------------------------------------------------------------------------
 
 #ifndef CERTI_FED_REGION_HH
@@ -28,10 +28,10 @@
 #include "certi.hh"
 #include "BaseRegion.hh"
 
-class RoutingSpace ;
-
 namespace certi {
 
+class RoutingSpace ;
+
 class CERTI_EXPORT FedRegion : public BaseRegion, public RTI::Region
 {
 public:
@@ -75,4 +75,4 @@
 
 #endif // CERTI_FED_REGION_HH
 
-// $Id: FedRegion.hh,v 3.2 2007/06/22 08:51:36 erk Exp $
+// $Id: FedRegion.hh,v 3.3 2008/06/23 13:25:05 erk Exp $

Index: libCERTI/Named.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/Named.hh,v
retrieving revision 3.4
retrieving revision 3.5
diff -u -b -r3.4 -r3.5
--- libCERTI/Named.hh   9 Dec 2007 16:26:49 -0000       3.4
+++ libCERTI/Named.hh   23 Jun 2008 13:25:05 -0000      3.5
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: Named.hh,v 3.4 2007/12/09 16:26:49 erk Exp $
+// $Id: Named.hh,v 3.5 2008/06/23 13:25:05 erk Exp $
 // ----------------------------------------------------------------------------
 
 #ifndef LIBCERTI_NAMED_HH
@@ -51,7 +51,7 @@
      * Constructor with inital value.
      * @param[in] name Initial name
      */        
-    Named(const std::string name);
+    Named(const std::string newName);
     
     /**
      * Virtual destructor.
@@ -63,13 +63,13 @@
      *  Set name.     
      *  @param[in] name the new name
      */
-    virtual void setName(const std::string name);
+    virtual void setName(const std::string newName);
     
     /**
      *  Set name (char* version)
      *  @param[in] name the new name
      */
-    virtual void setName(const char* name);
+    virtual void setName(const char* newName);
     
     /** 
      * Get name.
@@ -88,7 +88,7 @@
      * @param name String to compare
      * @return true if strings match
      */
-    bool isNamed(const std::string& name) const ;
+    bool isNamed(const std::string& newName) const ;
     
        /**
         * This method check if the provided name 
@@ -135,4 +135,4 @@
 
 #endif // LIBCERTI_NAMED_HH
 
-// $Id: Named.hh,v 3.4 2007/12/09 16:26:49 erk Exp $
+// $Id: Named.hh,v 3.5 2008/06/23 13:25:05 erk Exp $

Index: libCERTI/Clock.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/Clock.cc,v
retrieving revision 4.3
retrieving revision 4.4
diff -u -b -r4.3 -r4.4
--- libCERTI/Clock.cc   10 Aug 2007 11:32:16 -0000      4.3
+++ libCERTI/Clock.cc   23 Jun 2008 13:25:05 -0000      4.4
@@ -20,9 +20,9 @@
 #include "Clock.hh"
 namespace certi {
 
-Clock::Clock(const std::string name)
+Clock::Clock(const std::string newName)
 {
-       this->name = name;
+       name = newName;
 }
 
 uint64_t 

Index: libCERTI/ObjectClassSet.cc
===================================================================
RCS file: /sources/certi/certi/libCERTI/ObjectClassSet.cc,v
retrieving revision 3.37
retrieving revision 3.38
diff -u -b -r3.37 -r3.38
--- libCERTI/ObjectClassSet.cc  11 Jun 2008 15:19:22 -0000      3.37
+++ libCERTI/ObjectClassSet.cc  23 Jun 2008 13:25:05 -0000      3.38
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: ObjectClassSet.cc,v 3.37 2008/06/11 15:19:22 rousse Exp $
+// $Id: ObjectClassSet.cc,v 3.38 2008/06/23 13:25:05 erk Exp $
 // ----------------------------------------------------------------------------
 
 // Project
@@ -94,12 +94,12 @@
 
 // ----------------------------------------------------------------------------
 //! Constructor.
-ObjectClassSet::ObjectClassSet(SecurityServer *theSecurityServer, bool 
isRootClassSet)   
+ObjectClassSet::ObjectClassSet(SecurityServer *theSecurityServer, bool 
newIsRootClassSet)
 
 {
     // It can be NULL on the RTIA.
-    this->server = theSecurityServer ;
-    this->isRootClassSet = isRootClassSet;
+    server = theSecurityServer ;
+    isRootClassSet = newIsRootClassSet;
 }
 
 // ----------------------------------------------------------------------------
@@ -843,4 +843,4 @@
 
 } // namespace certi
 
-// $Id: ObjectClassSet.cc,v 3.37 2008/06/11 15:19:22 rousse Exp $
+// $Id: ObjectClassSet.cc,v 3.38 2008/06/23 13:25:05 erk Exp $

Index: test/Billard/Billard.cc
===================================================================
RCS file: /sources/certi/certi/test/Billard/Billard.cc,v
retrieving revision 3.37
retrieving revision 3.38
diff -u -b -r3.37 -r3.38
--- test/Billard/Billard.cc     16 Jun 2008 09:03:25 -0000      3.37
+++ test/Billard/Billard.cc     23 Jun 2008 13:25:05 -0000      3.38
@@ -855,13 +855,13 @@
           theParameters.size());
 
     for (unsigned int j = 0 ; j < theParameters.size(); ++j) {
-        RTI::ParameterHandle handle = theParameters.getHandle(j);
+        RTI::ParameterHandle parmHandle = theParameters.getHandle(j);
 
         valueLength = theParameters.getValueLength(j);
         parmValue = new char[valueLength] ;
         theParameters.getValue(j, parmValue, valueLength);
 
-        if (handle == ParamDXID) {
+        if (parmHandle == ParamDXID) {
             if (parmValue != NULL) {
                 // OLD : dx1 = atoi(parmValue);
                 double d_dx1 ;
@@ -875,7 +875,7 @@
                 D.Out(pdError, "Missing Attribute in RAV.");
         }
         else
-            if (handle == ParamDYID) {
+            if (parmHandle == ParamDYID) {
                 if (parmValue != NULL) {
                     // OLD : dy1 = atoi(parmValue);
                     double d_dy1 ;
@@ -889,7 +889,7 @@
                     D.Out(pdError, "Missing Attribute in RAV.");
             }
             else
-                if (handle == ParamBoulID) {
+                if (parmHandle == ParamBoulID) {
                     if (parmValue != NULL) {
                         // OLD : h1 = atoi(parmValue);
                         RTI::ObjectHandle d_h1 ;
@@ -937,12 +937,12 @@
 
     for (unsigned int j=0 ; j<theAttributes.size(); j++) {
 
-        RTI::AttributeHandle handle = theAttributes.getHandle(j);
+        RTI::AttributeHandle parmHandle = theAttributes.getHandle(j);
         valueLength = theAttributes.getValueLength(j);
         attrValue = new char[valueLength] ;
         theAttributes.getValue(j, attrValue, valueLength);
 
-        if (handle == AttrXID) {
+        if (parmHandle == AttrXID) {
             if (attrValue != NULL) {
                 // OLD : x1 = atof(attrValue);
                 double d_x1 ;
@@ -953,7 +953,7 @@
             else
                 D.Out(pdError, "Fed: ERREUR: missing Attribute.");
         }
-        else if (handle == AttrYID) {
+        else if (parmHandle == AttrYID) {
             if (attrValue != NULL) {
                 // OLD : y1 = atof(attrValue);
                 double d_y1 ;
@@ -1014,12 +1014,12 @@
 
     for (unsigned int j=0 ; j<theAttributes.size(); j++) {
 
-        RTI::AttributeHandle handle = theAttributes.getHandle(j);
+        RTI::AttributeHandle parmHandle = theAttributes.getHandle(j);
         valueLength = theAttributes.getValueLength(j);
         attrValue = new char[valueLength] ;
         theAttributes.getValue(j, attrValue, valueLength);
 
-        if (handle == AttrXID) {
+        if (parmHandle == AttrXID) {
             if (attrValue != NULL) {
                 // OLD : x1 = atof(attrValue);
                 double d_x1 ;
@@ -1030,7 +1030,7 @@
             else
                 D.Out(pdError, "Fed: ERREUR: missing Attribute.");
         }
-        else if (handle == AttrYID) {
+        else if (parmHandle == AttrYID) {
             if (attrValue != NULL) {
                 // OLD : y1 = atof(attrValue);
                 double d_y1 ;

Index: RTIA/FederationManagement.cc
===================================================================
RCS file: /sources/certi/certi/RTIA/FederationManagement.cc,v
retrieving revision 3.67
retrieving revision 3.68
diff -u -b -r3.67 -r3.68
--- RTIA/FederationManagement.cc        12 Jun 2008 07:39:51 -0000      3.67
+++ RTIA/FederationManagement.cc        23 Jun 2008 13:25:06 -0000      3.68
@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: FederationManagement.cc,v 3.67 2008/06/12 07:39:51 erk Exp $
+// $Id: FederationManagement.cc,v 3.68 2008/06/23 13:25:06 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -52,12 +52,12 @@
 
 // ----------------------------------------------------------------------------
 //! FederationManagement.
-  FederationManagement::FederationManagement(Communications *GC, Statistics* 
stat)
+  FederationManagement::FederationManagement(Communications *GC, Statistics* 
newStat)
     : savingState(false), restoringState(false)
 {
     G.Out(pdGendoc,"enter FederationManagement::FederationManagement");
     comm = GC ;
-    this->stat = stat ;
+    stat = newStat ;
     tm = NULL ;
 
     _numero_federation = 0 ;

Index: RTIG/Federation.cc
===================================================================
RCS file: /sources/certi/certi/RTIG/Federation.cc,v
retrieving revision 3.92
retrieving revision 3.93
diff -u -b -r3.92 -r3.93
--- RTIG/Federation.cc  16 Jun 2008 09:03:24 -0000      3.92
+++ RTIG/Federation.cc  23 Jun 2008 13:25:06 -0000      3.93
@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: Federation.cc,v 3.92 2008/06/16 09:03:24 rousse Exp $
+// $Id: Federation.cc,v 3.93 2008/06/23 13:25:06 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -281,14 +281,14 @@
 
             // Retrieve the FED file last modification time(for Audit)
             STAT_STRUCT StatBuffer ;
-            #if defined(_WIN32) && not defined(__MINGW32__)
+            #if defined(_WIN32) && !defined(__MINGW32__)
             char MTimeBuffer[26];
             #else
             char *MTimeBuffer ;
             #endif
 
             if (STAT_FUNCTION(filename.c_str(), &StatBuffer) == 0) {
-            #if defined(_WIN32) && not defined(__MINGW32__)                
+            #if defined(_WIN32) && !defined(__MINGW32__)                
                 ctime_s(&MTimeBuffer[0],26,&StatBuffer.st_mtime);
             #else
                 MTimeBuffer = ctime(&StatBuffer.st_mtime);
@@ -2279,5 +2279,5 @@
 
 }} // namespace certi/rtig
 
-// $Id: Federation.cc,v 3.92 2008/06/16 09:03:24 rousse Exp $
+// $Id: Federation.cc,v 3.93 2008/06/23 13:25:06 erk Exp $
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: libCERTI/Clock.hh
===================================================================
RCS file: /sources/certi/certi/libCERTI/Clock.hh,v
retrieving revision 4.4
retrieving revision 4.5
diff -u -b -r4.4 -r4.5
--- libCERTI/Clock.hh   28 Sep 2007 15:26:03 -0000      4.4
+++ libCERTI/Clock.hh   23 Jun 2008 13:25:05 -0000      4.5
@@ -44,14 +44,14 @@
 public:
        /**
         * The Clock default constructor.
         * @param[in] name the clock name
         */
-       Clock(const std::string name);
+       Clock(const std::string newName);
        /**
         * Get the clock name.
         * @return the clock name
         */
-       const std::string getName() {return name;}; 
+       const std::string getName() const {return name;}; 
        /**
         * Get the clock resolution in nano-seconds.
         * @return the clock resolution in nano-seconds
@@ -44,14 +44,14 @@
        /**
         * The Clock default constructor.
-        * @param[in] name the clock name
+        * @param[in] newName the clock name
         */
